.. youtube-dl-api-server documentation master file, created by
   sphinx-quickstart on Sun Mar 24 22:08:53 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

youtube-dl-api-server's documentation
=====================================

Contents:

.. toctree::
   :maxdepth: 2

   install
   server-manual
   api
   changelog
   about



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

